@@ -1,6 +1,3 @@
-from future import standard_library
-standard_library.install_aliases()
-
 import io
 from urllib.request import urlopen
 
