@@ -160,7 +160,13 @@ def recursive_parse(data_dict, samp_int_dict, path, counter, format=None,
         counter = parse_file_to_dict(data_dict, samp_int_dict, path, counter,
                                      format, verbose, quiet=quiet)
     elif os.path.isdir(path):
-        for file in (os.path.join(path, file) for file in os.listdir(path)):
+        try:
+            dirlist = os.listdir(path)
+        except PermissionError:
+            if verbose or not quiet:
+                print(f"Can not read directory {path} ('Permission denied')")
+            return counter
+        for file in (os.path.join(path, file) for file in dirlist):
             counter = recursive_parse(data_dict, samp_int_dict, file, counter,
                                       format, verbose, quiet, ignore_links)
     else:
@@ -416,7 +422,6 @@ class Scanner(object):
             height = len(labels) * 0.5
             height = max(4, height)
             fig.set_figheight(height)
-            plt.tight_layout()
 
             if not starttime or not endtime:
                 days = ax.get_xlim()
@@ -428,7 +433,11 @@ class Scanner(object):
             width = min(width, height * 4)
             fig.set_figwidth(width)
             plt.subplots_adjust(top=1, bottom=0, left=0, right=1)
-            plt.tight_layout()
+            with warnings.catch_warnings():
+                warnings.filterwarnings(
+                    "ignore", "The figure layout has changed to tight",
+                    UserWarning)
+                plt.tight_layout()
 
             fig.savefig(outfile)
             plt.close(fig)
